User's Guide
============

Installation
------------

You can install 

Quick Start
-----------

To get you running 

Reading Data
------------

h5py-Like Data Formats
----------------------

Experiment-Specific Data Processing
-----------------------------------


Beamline-Specific Helpers
-------------------------




